@@ -67,7 +67,9 @@ def main():
     try: 
         mlist = MailList.MailList(listname, lock=0)
     except Errors.MMListError, e:
-        FormatAdminOverview('No such list <em>%s</em>' % listname)
+        # Avoid cross-site scripting attack
+        safelistname = cgi.escape(listname)
+        FormatAdminOverview('No such list <em>%s</em>' % safelistname)
         syslog('error', 'Someone tried to access the admin interface for a '
                'non-existent list: %s' % listname)
         return
