@@ -30,6 +30,7 @@ import re
 import time
 import socket
 import random
+import cgi
 from UserDict import UserDict
 from types import StringType
 import random
@@ -610,7 +611,7 @@ def open_ex(filename, mode='r', bufsize=-1, perms=0664):
 
 
 
-def GetRequestURI(fallback=None):
+def GetRequestURI(fallback=None, escape=1):
     """Return the full virtual path this CGI script was invoked with.
 
     Newer web servers seems to supply this info in the REQUEST_URI
@@ -621,13 +622,17 @@ def GetRequestURI(fallback=None):
     Optional argument `fallback' (default `None') is returned if both of
     the above methods fail.
 
+    The url will be cgi escaped to prevent cross-site scripting attacks,
+    unless `escape' is set to 0.
     """
+    url = fallback
     if os.environ.has_key('REQUEST_URI'):
-        return os.environ['REQUEST_URI']
+        url = os.environ['REQUEST_URI']
     elif os.environ.has_key('SCRIPT_NAME') and os.environ.has_key('PATH_INFO'):
-        return os.environ['SCRIPT_NAME'] + os.environ['PATH_INFO']
-    else:
-        return fallback
+        url = os.environ['SCRIPT_NAME'] + os.environ['PATH_INFO']
+    if escape:
+        return cgi.escape(url)
+    return url
 
 
 
